CurrencyFormatter class abstract

Constructors

CurrencyFormatter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

format(dynamic amount, CurrencyFormatterSettings settings, {bool compact = false, int fractionDigits = 2, dynamic showThousandSeparator = true, dynamic currencyPlaceValueStyle, dynamic enforceDecimals = false}) List<String>
Format amount using the settings of a currency.
parse(String input, CurrencyFormatterSettings settings) num
Parse a formatted string to a number.